Module config

Module config 

Functions

fmt
Format the git configuration file at in_file, or the repository-local configuration if in_file is None, writing the result back in place, to out_file, or to out (stdout) respectively.
list_files
List all files which contributed sections to the resolved configuration, in precedence order.
show