pub struct Context {
pub output_statistics: Option<OutputFormat>,
pub thread_limit: Option<usize>,
pub verify_mode: Mode,
pub algorithm: Algorithm,
}Expand description
A general purpose context for many operations provided here
Fields
output_statistics: Option<OutputFormat>If set, provide statistics to out in the given format
thread_limit: Option<usize>If set, don’t use more than this amount of threads. Otherwise, usually use as many threads as there are logical cores. A value of 0 is interpreted as no-limit
verify_mode: Modealgorithm: AlgorithmAuto Trait Implementations
impl Freeze for Context
impl RefUnwindSafe for Context
impl Send for Context
impl Sync for Context
impl Unpin for Context
impl UnsafeUnpin for Context
impl UnwindSafe for Context