pub fn url(
repo: Repository,
name: Option<&str>,
direction: Direction,
all: bool,
out: impl Write,
) -> Result<()>Expand description
Print the effective URL or URLs of the selected remote.
Without an explicit remote, selection follows the fetch or push configuration for the current branch according to direction.